@@ -1,6 +1,6 @@
 """This module implements the ``Nothing`` part of the ``Maybe`` monad.
 
-SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
+
 """
 import os
 import typing as t
@@ -14,7 +14,7 @@ if t.TYPE_CHECKING or os.getenv('CG_GENERATING_DOCS'):  # pragma: no cover
     import cg_maybe
 
 _T = t.TypeVar('_T', covariant=True)
-_TT = t.TypeVar('_TT', covariant=True)
+_TT = t.TypeVar('_TT', covariant=True)  # pylint: disable=invalid-name
 _Y = t.TypeVar('_Y')
 _Z = t.TypeVar('_Z')
 
@@ -24,6 +24,9 @@ class _Nothing(t.Generic[_T]):
     """
     __slots__ = ()
 
+    def __hash__(self) -> int:
+        return hash('cg_maybe.Nothing')
+
     is_just: Literal[False] = False
     is_nothing: Literal[True] = True
 
@@ -46,8 +49,8 @@ class _Nothing(t.Generic[_T]):
     def map_or_default(
         self,
         mapper: t.Callable[[_T], _Y],
-        default: _Y,
-    ) -> _Y:
+        default: _Z,
+    ) -> _Z:
         return default
 
     def chain_nullable(
@@ -108,6 +111,11 @@ class _Nothing(t.Generic[_T]):
     def __repr__(self) -> str:
         return 'Nothing'
 
+    def __eq__(self, other: object) -> bool:
+        if isinstance(other, _Nothing):
+            return True
+        return NotImplemented
+
     def __structlog__(self) -> t.Mapping[str, object]:
         return {'type': 'Nothing'}
 
@@ -143,7 +151,7 @@ class _Nothing(t.Generic[_T]):
         return obj is Nothing or isinstance(obj, cls)
 
     def __bool__(self) -> Literal[False]:
-        raise Exception('Do not check Nothing for boolean value')
+        raise Exception('Do not check Nothing for boolean value')  # pylint: disable=broad-exception-raised
 
     def attr(self, attr: str) -> object:
         return Nothing
