@@ -2,6 +2,7 @@
 """
 import enum
 import uuid
+import types
 import typing as t
 import decimal
 import datetime
@@ -16,7 +17,7 @@ from ._enum import EnumValue, StringEnum
 from ._lazy import Lazy
 from ._list import List, TwoTuple
 from ._query import QueryParam
-from ._utils import USE_SLOTS, Literal, is_typeddict
+from ._utils import Literal, is_typeddict
 from ._literal import LiteralBoolean
 from ._mapping import (
     LookupMapping, BaseFixedMapping, OptionalArgument, RequiredArgument,
@@ -28,8 +29,7 @@ from ._rich_value import RichValue
 
 
 class _SkipConverter(Exception):
-    if USE_SLOTS:
-        __slots__ = ()
+    __slots__ = ()
 
 
 _ConvertPriority = t.NewType('_ConvertPriority', int)
@@ -39,8 +39,7 @@ _ConvertPriority = t.NewType('_ConvertPriority', int)
 class ConvertPriority:
     """The priority of a convert, the higher the earlier it will be called.
     """
-    if USE_SLOTS:
-        __slots__ = ('_prio', )
+    __slots__ = ('_prio', )
     _prio: _ConvertPriority
 
     @classmethod
@@ -227,12 +226,23 @@ def _get_args_typeddict(
     get_doc: t.Callable[[str], str] = lambda _: '',
 ) -> t.Sequence[t.Union[RequiredArgument, OptionalArgument]]:
     args: t.List[t.Union[RequiredArgument, OptionalArgument]] = []
-    annotations = t.get_type_hints(ctx.typ)
+    annotations = t.get_type_hints(ctx.typ, include_extras=True)
+    required_keys = set(ctx.typ.__required_keys__)
 
     for key, subtyp in annotations.items():
-        sub_parse = ctx.recurse_with_guard(subtyp)
         doc = get_doc(key)
-        if key in ctx.typ.__required_keys__:
+        origin = t.get_origin(subtyp)
+        # The reason for these checks:
+        # https://docs.python.org/3/library/typing.html#typing.TypedDict.__optional_keys__
+        if origin in (t.NotRequired, t.Required):
+            required = origin == t.Required
+            subtyp = subtyp.__args__[0]
+        else:
+            required = key in required_keys
+
+        sub_parse = ctx.recurse_with_guard(subtyp)
+
+        if required:
             args.append(
                 RequiredArgument(key, sub_parse, doc)  # type: ignore[misc]
             )
@@ -270,13 +280,14 @@ def _convert_list(ctx: ConvertCtx) -> Parser:
     ).use_readable_describe(ctx.readable)
 
 
-@as_converter(lambda x: x.origin == t.Union)
+@as_converter(
+    lambda x: x.origin == t.Union or isinstance(x.typ, types.UnionType)
+)
 def _convert_union(ctx: ConvertCtx) -> Parser:
     typ = ctx.typ
-    has_none = type(None) in typ.__args__
-    ctx.assert_not_query(not has_none)
-
     NoneType = type(None)
+    has_none = NoneType in typ.__args__
+
     non_nullable = [a for a in typ.__args__ if a != NoneType]
     parsers = [
         ctx.update_type(sub_type).convert() for sub_type in non_nullable
@@ -289,7 +300,10 @@ def _convert_union(ctx: ConvertCtx) -> Parser:
         res, *rest = parsers
         for item in rest:
             res = res | item
-    return Nullable(res) if has_none else res
+    if not ctx.from_query and has_none:
+        return Nullable(res)
+    else:
+        return res
 
 
 @as_converter(
