@@ -4,7 +4,6 @@ import enum
 import typing as t
 
 from ._base import Parser, SimpleValue
-from ._utils import USE_SLOTS as _USE_SLOTS
 from ._utils import T as _T
 from ._utils import type_to_name as _type_to_name
 from .exceptions import SimpleParseError
@@ -18,8 +17,7 @@ __all__ = ('StringEnum', 'EnumValue')
 class StringEnum(t.Generic[_T], Parser[_T]):
     """A parser for an list of allowed literal string values.
     """
-    if _USE_SLOTS:
-        __slots__ = ('opts', 'str_parser')
+    __slots__ = ('opts', 'str_parser')
 
     def __init__(
         self, *opts: str, str_parser: Parser[str] = SimpleValue.str
@@ -47,8 +45,7 @@ class StringEnum(t.Generic[_T], Parser[_T]):
 class EnumValue(t.Generic[_EnumT], Parser[_EnumT]):
     """A parser for an existing enum.
     """
-    if _USE_SLOTS:
-        __slots__ = ('__typ', )
+    __slots__ = ('__typ', )
 
     def __init__(self, typ: t.Type[_EnumT]) -> None:
         super().__init__()
