@@ -3,7 +3,6 @@
 import typing as t
 
 from ._base import Parser, SimpleValue
-from ._utils import USE_SLOTS as _USE_SLOTS
 from .exceptions import SimpleParseError
 from ._swagger_utils import OpenAPISchema
 
@@ -15,8 +14,7 @@ __all__ = ('LiteralBoolean', )
 class LiteralBoolean(t.Generic[_BoolT], Parser[_BoolT]):
     """A parser for a single literal boolean value.
     """
-    if _USE_SLOTS:
-        __slots__ = ('__value', )
+    __slots__ = ('__value', )
 
     def __init__(self, value: _BoolT) -> None:
         super().__init__()
