@@ -7,6 +7,7 @@ import typing as t
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
+from cg_maybe.utils import maybe_from_nullable
 
 from .. import parsers, utils
 
@@ -28,12 +29,16 @@ class AboutService(t.Generic[_ClientT]):
     def get(
         self,
         *,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        health: Maybe["str"] = Nothing,
+        tenant_id: Maybe["str"] = Nothing,
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "About":
         """Get information about this CodeGrade instance.
 
+        :param health: Key required to view instance health information.
+        :param tenant_id: The id of the tenant to get the site settings for.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
@@ -41,7 +46,15 @@ class AboutService(t.Generic[_ClientT]):
         """
 
         url = "/api/v1/about"
-        params = extra_parameters or {}
+        params: t.Dict[str, t.Any] = {
+            **(extra_parameters or {}),
+        }
+        maybe_from_nullable(t.cast(t.Any, health)).if_just(
+            lambda val: params.__setitem__("health", val)
+        )
+        maybe_from_nullable(t.cast(t.Any, tenant_id)).if_just(
+            lambda val: params.__setitem__("tenant_id", val)
+        )
 
         with self.__client as client:
             resp = client.http.get(url=url, params=params)
@@ -62,7 +75,7 @@ class AboutService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
