@@ -42,8 +42,8 @@ class CommentService(t.Generic[_ClientT]):
         self: "CommentService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CreateCommentData"],
         *,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Union[InlineFeedbackCommentBaseWithExtendedReplies, GeneralFeedbackCommentBaseWithExtendedReplies]":
         """Create a new comment base, or retrieve an existing one.
@@ -94,7 +94,7 @@ class CommentService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -105,8 +105,8 @@ class CommentService(t.Generic[_ClientT]):
         json_body: t.Union[dict, list, "CreateCommentReplyData"],
         *,
         comment_base_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Union[ExtendedNonDeletedCommentReply, DeletedCommentReply]":
         """Add a reply to a comment base.
@@ -155,7 +155,7 @@ class CommentService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -166,8 +166,8 @@ class CommentService(t.Generic[_ClientT]):
         *,
         comment_base_id: "int",
         reply_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "None":
         """Delete the given reply.
@@ -200,7 +200,7 @@ class CommentService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -212,8 +212,8 @@ class CommentService(t.Generic[_ClientT]):
         *,
         comment_base_id: "int",
         reply_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Union[ExtendedNonDeletedCommentReply, DeletedCommentReply]":
         """Update the content of a reply.
@@ -262,7 +262,7 @@ class CommentService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -273,8 +273,8 @@ class CommentService(t.Generic[_ClientT]):
         *,
         comment_base_id: "int",
         reply_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Sequence[CommentReplyEdit]":
         """Get the edits of a reply.
@@ -314,7 +314,7 @@ class CommentService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -325,8 +325,8 @@ class CommentService(t.Generic[_ClientT]):
         *,
         comment_base_id: "int",
         reply_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Union[ExtendedNonDeletedCommentReply, DeletedCommentReply]":
         """Update the approval status of a reply.
@@ -371,7 +371,7 @@ class CommentService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -382,8 +382,8 @@ class CommentService(t.Generic[_ClientT]):
         *,
         comment_base_id: "int",
         reply_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Union[ExtendedNonDeletedCommentReply, DeletedCommentReply]":
         """Update the approval status of a reply.
@@ -428,7 +428,7 @@ class CommentService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
