@@ -13,9 +13,9 @@ from .. import parsers, utils
 if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     import codegrade
 
-    from ..models.coupon import Coupon
     from ..models.coupon_data_parser import CouponDataParser
-    from ..models.coupon_usage import CouponUsage
+    from ..models.course_coupon import CourseCoupon
+    from ..models.course_coupon_usage import CourseCouponUsage
     from ..models.pay_with_coupon_course_price_data import (
         PayWithCouponCoursePriceData,
     )
@@ -23,6 +23,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
         StartPaymentCoursePriceData,
     )
     from ..models.started_transaction import StartedTransaction
+    from ..models.tenant_coupon_usage import TenantCouponUsage
 
 
 _ClientT = t.TypeVar("_ClientT", bound="codegrade.client._BaseClient")
@@ -38,10 +39,10 @@ class CoursePriceService(t.Generic[_ClientT]):
         self: "CoursePriceService[codegrade.client.AuthenticatedClient]",
         *,
         price_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
-    ) -> "t.Sequence[Coupon]":
+    ) -> "t.Sequence[CourseCoupon]":
         """Get the coupons of a price.
 
         :param price_id: The price id for which you want to get all coupons.
@@ -62,11 +63,11 @@ class CoursePriceService(t.Generic[_ClientT]):
 
         if utils.response_code_matches(resp.status_code, 200):
             # fmt: off
-            from ..models.coupon import CouponParser
+            from ..models.course_coupon import CourseCouponParser
 
             # fmt: on
             return parsers.JsonResponseParser(
-                rqa.List(CouponParser)
+                rqa.List(CourseCouponParser)
             ).try_parse(resp)
 
         from ..models.any_error import AnyError
@@ -75,7 +76,7 @@ class CoursePriceService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -86,10 +87,10 @@ class CoursePriceService(t.Generic[_ClientT]):
         json_body: t.Union[dict, list, "CouponDataParser"],
         *,
         price_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
-    ) -> "Coupon":
+    ) -> "CourseCoupon":
         """Create a new coupon for a course price.
 
         :param json_body: The body of the request. See
@@ -116,10 +117,12 @@ class CoursePriceService(t.Generic[_ClientT]):
 
         if utils.response_code_matches(resp.status_code, 200):
             # fmt: off
-            from ..models.coupon import CouponParser
+            from ..models.course_coupon import CourseCouponParser
 
             # fmt: on
-            return parsers.JsonResponseParser(CouponParser).try_parse(resp)
+            return parsers.JsonResponseParser(CourseCouponParser).try_parse(
+                resp
+            )
 
         from ..models.any_error import AnyError
 
@@ -127,7 +130,7 @@ class CoursePriceService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -138,8 +141,8 @@ class CoursePriceService(t.Generic[_ClientT]):
         *,
         price_id: "str",
         coupon_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "None":
         """Delete a coupon.
@@ -172,7 +175,7 @@ class CoursePriceService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -184,10 +187,10 @@ class CoursePriceService(t.Generic[_ClientT]):
         *,
         price_id: "str",
         coupon_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
-    ) -> "Coupon":
+    ) -> "CourseCoupon":
         """Update the given coupon with new values.
 
         :param json_body: The body of the request. See
@@ -215,10 +218,12 @@ class CoursePriceService(t.Generic[_ClientT]):
 
         if utils.response_code_matches(resp.status_code, 200):
             # fmt: off
-            from ..models.coupon import CouponParser
+            from ..models.course_coupon import CourseCouponParser
 
             # fmt: on
-            return parsers.JsonResponseParser(CouponParser).try_parse(resp)
+            return parsers.JsonResponseParser(CourseCouponParser).try_parse(
+                resp
+            )
 
         from ..models.any_error import AnyError
 
@@ -226,7 +231,7 @@ class CoursePriceService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -237,8 +242,8 @@ class CoursePriceService(t.Generic[_ClientT]):
         json_body: t.Union[dict, list, "StartPaymentCoursePriceData"],
         *,
         price_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "StartedTransaction":
         """Create a new payment for the current user.
@@ -280,7 +285,7 @@ class CoursePriceService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -291,10 +296,10 @@ class CoursePriceService(t.Generic[_ClientT]):
         json_body: t.Union[dict, list, "PayWithCouponCoursePriceData"],
         *,
         price_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
-    ) -> "CouponUsage":
+    ) -> "t.Union[TenantCouponUsage, CourseCouponUsage]":
         """Pay for a course with a coupon.
 
         :param json_body: The body of the request. See
@@ -321,11 +326,15 @@ class CoursePriceService(t.Generic[_ClientT]):
 
         if utils.response_code_matches(resp.status_code, 200):
             # fmt: off
-            from ..models.coupon_usage import CouponUsage
+            from ..models.course_coupon_usage import CourseCouponUsage
+            from ..models.tenant_coupon_usage import TenantCouponUsage
 
             # fmt: on
             return parsers.JsonResponseParser(
-                parsers.ParserFor.make(CouponUsage)
+                parsers.make_union(
+                    parsers.ParserFor.make(TenantCouponUsage),
+                    parsers.ParserFor.make(CourseCouponUsage),
+                )
             ).try_parse(resp)
 
         from ..models.any_error import AnyError
@@ -334,7 +343,7 @@ class CoursePriceService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
