@@ -30,8 +30,8 @@ class OAuthTokenService(t.Generic[_ClientT]):
     def get_all(
         self: "OAuthTokenService[codegrade.client.AuthenticatedClient]",
         *,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Sequence[OAuthToken]":
         """Get all OAuth tokens of the current user.
@@ -64,7 +64,7 @@ class OAuthTokenService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -74,8 +74,8 @@ class OAuthTokenService(t.Generic[_ClientT]):
         self: "OAuthTokenService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PostOAuthTokenData"],
         *,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "SetupOAuthResult":
         """Create an OAuth token for the specified provider.
@@ -114,7 +114,7 @@ class OAuthTokenService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -125,8 +125,8 @@ class OAuthTokenService(t.Generic[_ClientT]):
         *,
         token_id: "str",
         is_temp_id: "bool" = False,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "OAuthToken":
         """Get an OAuth token by id.
@@ -165,7 +165,7 @@ class OAuthTokenService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -175,8 +175,8 @@ class OAuthTokenService(t.Generic[_ClientT]):
         self: "OAuthTokenService[codegrade.client.AuthenticatedClient]",
         *,
         token_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "None":
         """Delete an OAuth token.
@@ -206,7 +206,7 @@ class OAuthTokenService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
