@@ -31,8 +31,8 @@ class SiteSettingsService(t.Generic[_ClientT]):
         self,
         *,
         only_frontend: "bool" = False,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Union[AllSiteSettings, FrontendSiteSettings]":
         """Get the settings for this CodeGrade instance.
@@ -73,7 +73,7 @@ class SiteSettingsService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -83,8 +83,8 @@ class SiteSettingsService(t.Generic[_ClientT]):
         self: "SiteSettingsService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PatchSiteSettingsData"],
         *,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "AllSiteSettings":
         """Update the settings for this CodeGrade instance.
@@ -123,7 +123,7 @@ class SiteSettingsService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
