@@ -38,8 +38,8 @@ class UserSettingService(t.Generic[_ClientT]):
         self,
         *,
         token: Maybe["str"] = Nothing,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "NotificationSetting":
         """Update preferences for notifications.
@@ -80,7 +80,7 @@ class UserSettingService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -93,8 +93,8 @@ class UserSettingService(t.Generic[_ClientT]):
         ],
         *,
         token: Maybe["str"] = Nothing,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "None":
         """Update preferences for notifications.
@@ -138,7 +138,7 @@ class UserSettingService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -149,8 +149,8 @@ class UserSettingService(t.Generic[_ClientT]):
         *,
         name: Maybe["str"] = Nothing,
         token: Maybe["str"] = Nothing,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "t.Union[PresentPreference, NonPresentPreference, t.Mapping[str, t.Any]]":
         """Get ui preferences.
@@ -200,7 +200,7 @@ class UserSettingService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
@@ -211,8 +211,8 @@ class UserSettingService(t.Generic[_ClientT]):
         json_body: t.Union[dict, list, "PatchUiPreferenceUserSettingData"],
         *,
         token: Maybe["str"] = Nothing,
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
+        extra_parameters: t.Optional[
+            t.Mapping[str, t.Union[str, bool, int, float]]
         ] = None,
     ) -> "None":
         """Update ui preferences.
@@ -255,7 +255,7 @@ class UserSettingService(t.Generic[_ClientT]):
             resp,
             (
                 (
-                    (400, 409, 401, 403, 404, "5XX"),
+                    (400, 409, 401, 403, 404, 429, 500),
                     utils.unpack_union(AnyError),
                 ),
             ),
