@@ -202,9 +202,9 @@ class _BaseClient:
 
     def __exit__(
         self,
-        exc_type: t.Type[BaseException] = None,
-        exc_value: BaseException = None,
-        traceback: TracebackType = None,
+        exc_type: t.Optional[t.Type[BaseException]] = None,
+        exc_value: t.Optional[BaseException] = None,
+        traceback: t.Optional[TracebackType] = None,
     ) -> None:
         self.__open_level -= 1
         if self.__open_level == 0:
@@ -523,7 +523,13 @@ class Client(_BaseClient):
     __slots__ = ()
 
     def _make_http(self) -> httpx.Client:
-        return httpx.Client(base_url=self.base_url)
+        return httpx.Client(
+            base_url=self.base_url,
+            headers={
+                "User-Agent": "CodeGradeAPI/16.1.51",
+            },
+            follow_redirects=True,
+        )
 
 
 class AuthenticatedClient(_BaseClient):
@@ -538,7 +544,11 @@ class AuthenticatedClient(_BaseClient):
     def _make_http(self) -> httpx.Client:
         return httpx.Client(
             base_url=self.base_url,
-            headers={"Authorization": f"Bearer {self.token}"},
+            headers={
+                "Authorization": f"Bearer {self.token}",
+                "User-Agent": "CodeGradeAPI/16.1.51",
+            },
+            follow_redirects=True,
         )
 
     @staticmethod
@@ -555,7 +565,7 @@ class AuthenticatedClient(_BaseClient):
         cls,
         username: str,
         password: str,
-        tenant: str = None,
+        tenant: t.Optional[str] = None,
         host: str = _DEFAULT_HOST,
     ) -> "AuthenticatedClient":
         """Get an :class:`.AuthenticatedClient` by logging in with your
