@@ -31,6 +31,9 @@ from .assignment_default_grading_scale_setting import (
 from .assignment_description_enabled_setting import (
     AssignmentDescriptionEnabledSetting,
 )
+from .assignment_description_on_teachers_submissions_page_setting import (
+    AssignmentDescriptionOnTeachersSubmissionsPageSetting,
+)
 from .assignment_done_type import AssignmentDoneType
 from .assignment_export_column import AssignmentExportColumn
 from .assignment_feedback import AssignmentFeedback
@@ -55,8 +58,11 @@ from .assignment_percentage_grading_settings import (
 )
 from .assignment_point_decimals_setting import AssignmentPointDecimalsSetting
 from .assignment_points_grading_settings import AssignmentPointsGradingSettings
+from .assignment_section_timeframe import AssignmentSectionTimeframe
 from .assignment_state_enum import AssignmentStateEnum
+from .assignment_submission_mode import AssignmentSubmissionMode
 from .assignment_template import AssignmentTemplate
+from .assignment_timeframes import AssignmentTimeframes
 from .at_image_caching_enabled_setting import AtImageCachingEnabledSetting
 from .auto_test import AutoTest
 from .auto_test_capture_points_message_setting import (
@@ -137,7 +143,7 @@ from .base_comment_base_with_normal_replies import (
     BaseCommentBaseWithNormalReplies,
 )
 from .base_comment_reply import BaseCommentReply
-from .base_coupon import BaseCoupon
+from .base_course_coupon import BaseCourseCoupon
 from .base_directory import BaseDirectory
 from .base_error import BaseError
 from .base_file import BaseFile
@@ -148,6 +154,7 @@ from .base_lti_provider import BaseLTIProvider
 from .base_notification import BaseNotification
 from .base_release_info import BaseReleaseInfo
 from .base_rubric_item import BaseRubricItem
+from .base_tenant_coupon import BaseTenantCoupon
 from .blackboard_zip_upload_enabled_setting import (
     BlackboardZipUploadEnabledSetting,
 )
@@ -162,6 +169,9 @@ from .check_points_data import CheckPointsData
 from .check_points_extra import CheckPointsExtra
 from .check_points_input_as_json import CheckPointsInputAsJSON
 from .clone_result import CloneResult
+from .code_editor_output_viewer_title_setting import (
+    CodeEditorOutputViewerTitleSetting,
+)
 from .code_quality_as_json import CodeQualityAsJSON
 from .code_quality_base_data import CodeQualityBaseData
 from .code_quality_data import CodeQualityData
@@ -174,14 +184,16 @@ from .comment_reply import CommentReply
 from .comment_reply_edit import CommentReplyEdit
 from .comment_reply_type import CommentReplyType
 from .comment_type import CommentType
+from .community_library_publishing_setting import (
+    CommunityLibraryPublishingSetting,
+)
+from .community_library_setting import CommunityLibrarySetting
 from .connect_repository_git_provider_data import (
     ConnectRepositoryGitProviderData,
 )
 from .copy_auto_test_data import CopyAutoTestData
 from .copy_rubric_assignment_data import CopyRubricAssignmentData
-from .coupon import Coupon
 from .coupon_data_parser import CouponDataParser
-from .coupon_usage import CouponUsage
 from .coupon_with_code import CouponWithCode
 from .coupon_without_code import CouponWithoutCode
 from .course import Course
@@ -189,11 +201,14 @@ from .course_bulk_enroll_result import CourseBulkEnrollResult
 from .course_bulk_register_enabled_setting import (
     CourseBulkRegisterEnabledSetting,
 )
+from .course_coupon import CourseCoupon
+from .course_coupon_usage import CourseCouponUsage
 from .course_gradebook_enabled_setting import CourseGradebookEnabledSetting
 from .course_gradebook_render_warning_size_setting import (
     CourseGradebookRenderWarningSizeSetting,
 )
 from .course_of_course_price import CourseOfCoursePrice
+from .course_of_tenant_coupon_usage import CourseOfTenantCouponUsage
 from .course_perm_map import CoursePermMap
 from .course_permission import CoursePermission
 from .course_price import CoursePrice
@@ -240,6 +255,10 @@ from .custom_output_extra import CustomOutputExtra
 from .custom_output_input_as_json import CustomOutputInputAsJSON
 from .custom_output_log import CustomOutputLog
 from .custom_output_log_base import CustomOutputLogBase
+from .default_course_ta_role_setting import DefaultCourseTaRoleSetting
+from .default_course_teacher_role_setting import (
+    DefaultCourseTeacherRoleSetting,
+)
 from .deleted_comment_reply import DeletedCommentReply
 from .deletion_type import DeletionType
 from .directory_with_children import DirectoryWithChildren
@@ -283,8 +302,6 @@ from .file_tree import FileTree
 from .file_type import FileType
 from .finalized_lti1p1_provider import FinalizedLTI1p1Provider
 from .finalized_lti1p3_provider import FinalizedLTI1p3Provider
-from .find_element_interval_setting import FindElementIntervalSetting
-from .find_element_max_tries_setting import FindElementMaxTriesSetting
 from .first_phase_lti_launch_exception import FirstPhaseLTILaunchException
 from .fixed_availability import FixedAvailability
 from .fixed_grade_availability import FixedGradeAvailability
@@ -299,10 +316,16 @@ from .general_feedback_extra import GeneralFeedbackExtra
 from .git_repositories_page import GitRepositoriesPage
 from .git_repository_like import GitRepositoryLike
 from .git_user_info import GitUserInfo
+from .github_template_repo_enabled_setting import (
+    GithubTemplateRepoEnabledSetting,
+)
 from .global_perm_map import GlobalPermMap
 from .global_permission import GlobalPermission
 from .grade_history import GradeHistory
 from .grade_origin import GradeOrigin
+from .grade_viewer_and_editor_on_submission_enabled_setting import (
+    GradeViewerAndEditorOnSubmissionEnabledSetting,
+)
 from .grading_notifications_enabled_setting import (
     GradingNotificationsEnabledSetting,
 )
@@ -314,6 +337,12 @@ from .group_set import GroupSet
 from .groups_enabled_setting import GroupsEnabledSetting
 from .has_unread_notifcation_json import HasUnreadNotifcationJSON
 from .health_information import HealthInformation
+from .hide_code_editor_output_viewer_with_only_quiz_steps_setting import (
+    HideCodeEditorOutputViewerWithOnlyQuizStepsSetting,
+)
+from .hide_empty_rubric_row_description_setting import (
+    HideEmptyRubricRowDescriptionSetting,
+)
 from .ignore_handling import IgnoreHandling
 from .ignored_files_exception import IgnoredFilesException
 from .import_into_assignment_data import ImportIntoAssignmentData
@@ -326,6 +355,9 @@ from .inline_feedback_comment_base_with_extended_replies import (
     InlineFeedbackCommentBaseWithExtendedReplies,
 )
 from .inline_feedback_extra import InlineFeedbackExtra
+from .inline_rubric_viewer_enabled_setting import (
+    InlineRubricViewerEnabledSetting,
+)
 from .invalid_group_exception import InvalidGroupException
 from .invalid_io_cases_exception import InvalidIOCasesException
 from .invalid_options_exception import InvalidOptionsException
@@ -362,18 +394,39 @@ from .linters_enabled_setting import LintersEnabledSetting
 from .lms_capabilities import LMSCapabilities
 from .login_token_before_time_setting import LoginTokenBeforeTimeSetting
 from .login_user_data import LoginUserData
+from .logout_response import LogoutResponse
+from .logout_user_data import LogoutUserData
 from .lti1p1_provider import LTI1p1Provider
 from .lti1p1_provider_data import LTI1p1ProviderData
+from .lti1p3_nonce_and_state_validation_enabled_setting import (
+    Lti1p3NonceAndStateValidationEnabledSetting,
+)
+from .lti1p3_parse_most_privileged_role_setting import (
+    Lti1p3ParseMostPrivilegedRoleSetting,
+)
+from .lti1p3_prevent_nonce_reuse_enabled_setting import (
+    Lti1p3PreventNonceReuseEnabledSetting,
+)
 from .lti1p3_provider import LTI1p3Provider
 from .lti1p3_provider_data import LTI1p3ProviderData
 from .lti1p3_provider_presentation_as_json import (
     LTI1p3ProviderPresentationAsJSON,
 )
+from .lti1p3_system_role_from_context_role_setting import (
+    Lti1p3SystemRoleFromContextRoleSetting,
+)
 from .lti_enabled_setting import LtiEnabledSetting
+from .lti_first_launch_content_id_enabled_setting import (
+    LtiFirstLaunchContentIdEnabledSetting,
+)
+from .lti_launch_data_logging_setting import LtiLaunchDataLoggingSetting
 from .lti_lock_date_copying_enabled_setting import (
     LtiLockDateCopyingEnabledSetting,
 )
 from .lti_provider_base import LTIProviderBase
+from .lti_unset_deadline_lock_date_enabled_setting import (
+    LtiUnsetDeadlineLockDateEnabledSetting,
+)
 from .max_document_update_size_setting import MaxDocumentUpdateSizeSetting
 from .max_dynamo_file_size_setting import MaxDynamoFileSizeSetting
 from .max_dynamo_submission_size_setting import MaxDynamoSubmissionSizeSetting
@@ -385,23 +438,6 @@ from .max_normal_upload_size_setting import MaxNormalUploadSizeSetting
 from .max_number_of_files_setting import MaxNumberOfFilesSetting
 from .max_plagiarism_matches_setting import MaxPlagiarismMatchesSetting
 from .max_user_setting_amount_setting import MaxUserSettingAmountSetting
-from .metric_evaluation_time_chunk_size_setting import (
-    MetricEvaluationTimeChunkSizeSetting,
-)
-from .metric_evaluation_time_limit_setting import (
-    MetricEvaluationTimeLimitSetting,
-)
-from .metric_event_buffer_size_setting import MetricEventBufferSizeSetting
-from .metric_gathering_enabled_setting import MetricGatheringEnabledSetting
-from .metric_gathering_event_interval_setting import (
-    MetricGatheringEventIntervalSetting,
-)
-from .metric_gathering_expressions_setting import (
-    MetricGatheringExpressionsSetting,
-)
-from .metric_gathering_time_interval_setting import (
-    MetricGatheringTimeIntervalSetting,
-)
 from .min_password_score_setting import MinPasswordScoreSetting
 from .mirror_file_result import MirrorFileResult
 from .missing_cookie_error import MissingCookieError
@@ -421,6 +457,9 @@ from .new_auto_test_copying_enabled_setting import (
 from .new_auto_test_current_initial_build_ids_setting import (
     NewAutoTestCurrentInitialBuildIdsSetting,
 )
+from .new_auto_test_diff_viewer_enabled_setting import (
+    NewAutoTestDiffViewerEnabledSetting,
+)
 from .new_auto_test_enabled_setting import NewAutoTestEnabledSetting
 from .new_auto_test_initial_build_id_setting import (
     NewAutoTestInitialBuildIdSetting,
@@ -429,6 +468,9 @@ from .new_auto_test_max_dynamodb_size_setting import (
     NewAutoTestMaxDynamodbSizeSetting,
 )
 from .new_auto_test_max_file_size_setting import NewAutoTestMaxFileSizeSetting
+from .new_auto_test_max_output_files_size_setting import (
+    NewAutoTestMaxOutputFilesSizeSetting,
+)
 from .new_auto_test_max_storage_size_setting import (
     NewAutoTestMaxStorageSizeSetting,
 )
@@ -441,6 +483,9 @@ from .new_auto_test_test_max_command_time_setting import (
 from .new_auto_test_test_output_limit_setting import (
     NewAutoTestTestOutputLimitSetting,
 )
+from .new_auto_test_uncollapsing_step_output_delay_setting import (
+    NewAutoTestUncollapsingStepOutputDelaySetting,
+)
 from .no_permissions import NoPermissions
 from .non_deleted_comment_reply import NonDeletedCommentReply
 from .non_finalized_lti1p1_provider import NonFinalizedLTI1p1Provider
@@ -462,8 +507,10 @@ from .oauth_provider import OAuthProvider
 from .oauth_token import OAuthToken
 from .option import Option
 from .options_input_data import OptionsInputData
+from .output_viewer_animation_limit_lines_count_setting import (
+    OutputViewerAnimationLimitLinesCountSetting,
+)
 from .parse_api_exception import ParseAPIException
-from .partial_all_site_settings import PartialAllSiteSettings
 from .patch1_p1_provider_lti_data import Patch1P1ProviderLTIData
 from .patch1_p3_provider_lti_data import Patch1P3ProviderLTIData
 from .patch_all_notification_data import PatchAllNotificationData
@@ -499,8 +546,19 @@ from .patch_ui_preference_user_setting_data import (
 )
 from .patch_user_data import PatchUserData
 from .pay_with_coupon_course_price_data import PayWithCouponCoursePriceData
+from .pearson_templates_setting import PearsonTemplatesSetting
 from .peer_feedback_enabled_setting import PeerFeedbackEnabledSetting
 from .permission_exception import PermissionException
+from .plagiarism_bulk_export_enabled_setting import (
+    PlagiarismBulkExportEnabledSetting,
+)
+from .plagiarism_bulk_export_max_cases_setting import (
+    PlagiarismBulkExportMaxCasesSetting,
+)
+from .plagiarism_case import PlagiarismCase
+from .plagiarism_pdf_export_enabled_setting import (
+    PlagiarismPdfExportEnabledSetting,
+)
 from .plagiarism_run import PlagiarismRun
 from .plagiarism_run_plagiarism_assignment_as_json import (
     PlagiarismRunPlagiarismAssignmentAsJSON,
@@ -518,6 +576,9 @@ from .put_price_course_data import PutPriceCourseData
 from .put_price_tenant_data import PutPriceTenantData
 from .put_rubric_assignment_data import PutRubricAssignmentData
 from .quality_comment_severity import QualityCommentSeverity
+from .quality_comments_in_code_editor_setting import (
+    QualityCommentsInCodeEditorSetting,
+)
 from .quality_test_log import QualityTestLog
 from .quality_test_log_base import QualityTestLogBase
 from .register_enabled_setting import RegisterEnabledSetting
@@ -560,6 +621,9 @@ from .run_program_input_as_json import RunProgramInputAsJSON
 from .run_program_log import RunProgramLog
 from .saml2_provider_json import Saml2ProviderJSON
 from .saml_ui_info import SamlUiInfo
+from .sections_in_submission_list_enabled_setting import (
+    SectionsInSubmissionListEnabledSetting,
+)
 from .send_registration_email_setting import SendRegistrationEmailSetting
 from .server_time_correction_enabled_setting import (
     ServerTimeCorrectionEnabledSetting,
@@ -568,12 +632,22 @@ from .server_time_diff_tolerance_setting import ServerTimeDiffToleranceSetting
 from .server_time_sync_interval_setting import ServerTimeSyncIntervalSetting
 from .setting_token_time_setting import SettingTokenTimeSetting
 from .setup_oauth_result import SetupOAuthResult
+from .simple_submission_mode_enabled_setting import (
+    SimpleSubmissionModeEnabledSetting,
+)
+from .simple_submission_navigate_to_latest_editor_session_setting import (
+    SimpleSubmissionNavigateToLatestEditorSessionSetting,
+)
 from .site_email_setting import SiteEmailSetting
 from .site_setting_input import SiteSettingInput
 from .snippet import Snippet
+from .sso_infer_global_staff_role_setting import SsoInferGlobalStaffRoleSetting
 from .sso_username_decollision_enabled_setting import (
     SsoUsernameDecollisionEnabledSetting,
 )
+from .staged_assignment_importer_enabled_setting import (
+    StagedAssignmentImporterEnabledSetting,
+)
 from .start_payment_course_price_close_tab_data import (
     StartPaymentCoursePriceCloseTabData,
 )
@@ -584,9 +658,19 @@ from .start_payment_course_price_redirect_data import (
 from .started_transaction import StartedTransaction
 from .student_payment_enabled_setting import StudentPaymentEnabledSetting
 from .submission_validator_input_data import SubmissionValidatorInputData
+from .submissions_page_v2_enabled_setting import (
+    SubmissionsPageV2EnabledSetting,
+)
+from .submissions_per_page_enabled_setting import (
+    SubmissionsPerPageEnabledSetting,
+)
 from .task_result_state import TaskResultState
 from .tax_behavior import TaxBehavior
 from .tenant import Tenant
+from .tenant_coupon import TenantCoupon
+from .tenant_coupon_usage import TenantCouponUsage
+from .tenant_coupon_with_code import TenantCouponWithCode
+from .tenant_coupon_without_code import TenantCouponWithoutCode
 from .tenant_course_statistics import TenantCourseStatistics
 from .tenant_of_tenant_price import TenantOfTenantPrice
 from .tenant_permissions import TenantPermissions
@@ -597,9 +681,8 @@ from .test_submission_copying_on_import_enabled_setting import (
     TestSubmissionCopyingOnImportEnabledSetting,
 )
 from .timed_availability import TimedAvailability
+from .timeframe_like import TimeframeLike
 from .token_revoked_exception import TokenRevokedException
-from .tour_configurations_setting import TourConfigurationsSetting
-from .tour_polling_interval_setting import TourPollingIntervalSetting
 from .transaction import Transaction
 from .transaction_state import TransactionState
 from .types import *
@@ -619,6 +702,12 @@ from .user_without_group import UserWithoutGroup
 from .weak_password_exception import WeakPasswordException
 from .weak_password_feedback import WeakPasswordFeedback
 from .webhook_base import WebhookBase
+from .webhook_configuration_disabled_as_json import (
+    WebhookConfigurationDisabledAsJSON,
+)
+from .webhook_configuration_enabled_as_json import (
+    WebhookConfigurationEnabledAsJSON,
+)
 from .work import Work
 from .work_origin import WorkOrigin
 from .work_rubric_item import WorkRubricItem
