@@ -271,6 +271,18 @@ class CoursePermMap:
     #: would look like as an experiment, without having to enable it for the
     #: students.
     can_always_use_all_upload_types: "bool"
+    #: Users with this permission can view the which members are part of the
+    #: course sections they are a member of.
+    can_view_own_course_section_members: "bool"
+    #: Users with this permission can view all schedules, even those that don't
+    #: apply to them.
+    can_view_all_assignment_timeframes: "bool"
+    #: Users with this permission can create test submissions in the
+    #: assignments of this course.
+    can_create_test_submissions: "bool"
+    #: Users with this permission are allowed to see the details of Pearson
+    #: templates in a course (context).
+    can_view_pearson_context_templates: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -973,6 +985,38 @@ class CoursePermMap:
                     " enable it for the students."
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_view_own_course_section_members",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can view the which members are"
+                    " part of the course sections they are a member of."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_all_assignment_timeframes",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can view all schedules, even"
+                    " those that don't apply to them."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_create_test_submissions",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission can create test submissions in"
+                    " the assignments of this course."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "can_view_pearson_context_templates",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Users with this permission are allowed to see the details"
+                    " of Pearson templates in a course (context)."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -1132,6 +1176,18 @@ class CoursePermMap:
             "can_always_use_all_upload_types": to_dict(
                 self.can_always_use_all_upload_types
             ),
+            "can_view_own_course_section_members": to_dict(
+                self.can_view_own_course_section_members
+            ),
+            "can_view_all_assignment_timeframes": to_dict(
+                self.can_view_all_assignment_timeframes
+            ),
+            "can_create_test_submissions": to_dict(
+                self.can_create_test_submissions
+            ),
+            "can_view_pearson_context_templates": to_dict(
+                self.can_view_pearson_context_templates
+            ),
         }
         return res
 
@@ -1224,6 +1280,10 @@ class CoursePermMap:
             can_view_new_autotest_hidden_step_results=parsed.can_view_new_autotest_hidden_step_results,
             can_view_new_autotest_hidden_step_output=parsed.can_view_new_autotest_hidden_step_output,
             can_always_use_all_upload_types=parsed.can_always_use_all_upload_types,
+            can_view_own_course_section_members=parsed.can_view_own_course_section_members,
+            can_view_all_assignment_timeframes=parsed.can_view_all_assignment_timeframes,
+            can_create_test_submissions=parsed.can_create_test_submissions,
+            can_view_pearson_context_templates=parsed.can_view_pearson_context_templates,
         )
         res.raw_data = d
         return res
