@@ -102,3 +102,7 @@ class CoursePermission(str, Enum):
         "can_view_new_autotest_hidden_step_output"
     )
     can_always_use_all_upload_types = "can_always_use_all_upload_types"
+    can_view_own_course_section_members = "can_view_own_course_section_members"
+    can_view_all_assignment_timeframes = "can_view_all_assignment_timeframes"
+    can_create_test_submissions = "can_create_test_submissions"
+    can_view_pearson_context_templates = "can_view_pearson_context_templates"
