@@ -80,6 +80,7 @@ class ExtendedWork(Work):
             "assignee": to_dict(self.assignee),
             "grade_overridden": to_dict(self.grade_overridden),
             "extra_info": to_dict(self.extra_info),
+            "timeframe": to_dict(self.timeframe),
         }
         return res
 
@@ -102,6 +103,7 @@ class ExtendedWork(Work):
             assignee=parsed.assignee,
             grade_overridden=parsed.grade_overridden,
             extra_info=parsed.extra_info,
+            timeframe=parsed.timeframe,
         )
         res.raw_data = d
         return res
@@ -113,6 +115,7 @@ if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
     # fmt: off
     import datetime
 
+    from .timeframe_like import TimeframeLike
     from .work_origin import WorkOrigin
 
     # fmt: on
