@@ -45,6 +45,7 @@ class FinalizedLTI1p3Provider(BaseLTI1p3Provider):
             "created_at": to_dict(self.created_at),
             "intended_use": to_dict(self.intended_use),
             "tenant_id": to_dict(self.tenant_id),
+            "label": to_dict(self.label),
         }
         return res
 
@@ -65,6 +66,7 @@ class FinalizedLTI1p3Provider(BaseLTI1p3Provider):
             created_at=parsed.created_at,
             intended_use=parsed.intended_use,
             tenant_id=parsed.tenant_id,
+            label=parsed.label,
         )
         res.raw_data = d
         return res
