@@ -22,7 +22,7 @@ class LTI1p3ProviderData:
     #: The iss of the new provider
     iss: "str"
     #: The LMS that will be used for this connection
-    lms: "t.Literal['Canvas', 'Blackboard', 'Moodle', 'Brightspace']"
+    lms: "t.Literal['Canvas', 'Blackboard', 'Moodle', 'Brightspace', 'Revel']"
     #: Use LTI 1.3
     lti_version: "t.Literal['lti1.3']"
     #: Label for the LTI provider
@@ -45,7 +45,7 @@ class LTI1p3ProviderData:
             rqa.RequiredArgument(
                 "lms",
                 rqa.StringEnum(
-                    "Canvas", "Blackboard", "Moodle", "Brightspace"
+                    "Canvas", "Blackboard", "Moodle", "Brightspace", "Revel"
                 ),
                 doc="The LMS that will be used for this connection",
             ),
