@@ -21,6 +21,7 @@ from .assignment_percentage_grading_settings import (
 )
 from .assignment_points_grading_settings import AssignmentPointsGradingSettings
 from .assignment_state_enum import AssignmentStateEnum
+from .assignment_submission_mode import AssignmentSubmissionMode
 from .fixed_availability import FixedAvailability
 from .fixed_grade_availability import FixedGradeAvailability
 from .submission_validator_input_data import SubmissionValidatorInputData
@@ -77,7 +78,7 @@ class PatchAssignmentData:
     #: used when `reminder_time` is `null`.
     done_type: Maybe["t.Optional[AssignmentDoneType]"] = Nothing
     #: At what time should we send the reminder emails to the graders. This
-    #: value is not used wehn `done_type` is `null`.
+    #: value is not used when `done_type` is `null`.
     reminder_time: Maybe["t.Optional[datetime.datetime]"] = Nothing
     #: A list of emails that should receive an email when grading is done. This
     #: value has no effect when `done_type` is set to `null`.
@@ -86,7 +87,7 @@ class PatchAssignmentData:
     anonymized_grading: Maybe[
         "t.Optional[AssignmentAnonymizationAlgo]"
     ] = Nothing
-    #: The file we should load first in an asignment
+    #: The file we should load first in an assignment
     file_to_load_first: Maybe["t.Optional[str]"] = Nothing
     #: Grading settings of this assignment.
     grading: Maybe[
@@ -99,6 +100,8 @@ class PatchAssignmentData:
     ] = Nothing
     #: The grade availability of this assignment.
     grade_availability: Maybe["FixedGradeAvailability"] = Nothing
+    #: The submission mode of this assignment
+    submission_mode: Maybe["AssignmentSubmissionMode"] = Nothing
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -238,7 +241,7 @@ class PatchAssignmentData:
                 rqa.Nullable(rqa.RichValue.DateTime),
                 doc=(
                     "At what time should we send the reminder emails to the"
-                    " graders. This value is not used wehn `done_type` is"
+                    " graders. This value is not used when `done_type` is"
                     " `null`."
                 ),
             ),
@@ -261,7 +264,7 @@ class PatchAssignmentData:
             rqa.OptionalArgument(
                 "file_to_load_first",
                 rqa.Nullable(rqa.SimpleValue.str),
-                doc="The file we should load first in an asignment",
+                doc="The file we should load first in an assignment",
             ),
             rqa.OptionalArgument(
                 "grading",
@@ -286,6 +289,11 @@ class PatchAssignmentData:
                 parsers.ParserFor.make(FixedGradeAvailability),
                 doc="The grade availability of this assignment.",
             ),
+            rqa.OptionalArgument(
+                "submission_mode",
+                rqa.EnumValue(AssignmentSubmissionMode),
+                doc="The submission mode of this assignment",
+            ),
         ).use_readable_describe(True)
     )
 
@@ -321,6 +329,7 @@ class PatchAssignmentData:
         self.grading = maybe_from_nullable(self.grading)
         self.availability = maybe_from_nullable(self.availability)
         self.grade_availability = maybe_from_nullable(self.grade_availability)
+        self.submission_mode = maybe_from_nullable(self.submission_mode)
 
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {}
@@ -378,6 +387,8 @@ class PatchAssignmentData:
             res["availability"] = to_dict(self.availability.value)
         if self.grade_availability.is_just:
             res["grade_availability"] = to_dict(self.grade_availability.value)
+        if self.submission_mode.is_just:
+            res["submission_mode"] = to_dict(self.submission_mode.value)
         return res
 
     @classmethod
@@ -411,6 +422,7 @@ class PatchAssignmentData:
             grading=parsed.grading,
             availability=parsed.availability,
             grade_availability=parsed.grade_availability,
+            submission_mode=parsed.submission_mode,
         )
         res.raw_data = d
         return res
