@@ -8,9 +8,7 @@ from dataclasses import dataclass, field
 
 import cg_request_args as rqa
 
-from .. import parsers
 from ..utils import to_dict
-from .ui_preference_name import UIPreferenceName
 
 
 @dataclass
@@ -18,9 +16,9 @@ class PatchUiPreferenceUserSettingData:
     """Input data required for the `User Setting::PatchUiPreference` operation."""
 
     #: The ui preference you want to change.
-    name: "UIPreferenceName"
+    name: "str"
     #: The new value of the preference.
-    value: "bool"
+    value: "t.Any"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -28,12 +26,12 @@ class PatchUiPreferenceUserSettingData:
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "name",
-                rqa.EnumValue(UIPreferenceName),
+                rqa.SimpleValue.str,
                 doc="The ui preference you want to change.",
             ),
             rqa.RequiredArgument(
                 "value",
-                rqa.SimpleValue.bool,
+                rqa.AnyValue,
                 doc="The new value of the preference.",
             ),
         ).use_readable_describe(True)
