@@ -19,6 +19,9 @@ from .assignment_default_grading_scale_setting import (
 from .assignment_description_enabled_setting import (
     AssignmentDescriptionEnabledSetting,
 )
+from .assignment_description_on_teachers_submissions_page_setting import (
+    AssignmentDescriptionOnTeachersSubmissionsPageSetting,
+)
 from .assignment_grading_scale_points_enabled_setting import (
     AssignmentGradingScalePointsEnabledSetting,
 )
@@ -83,6 +86,13 @@ from .blackboard_zip_upload_enabled_setting import (
 from .canvas_course_id_copying_enabled_setting import (
     CanvasCourseIdCopyingEnabledSetting,
 )
+from .code_editor_output_viewer_title_setting import (
+    CodeEditorOutputViewerTitleSetting,
+)
+from .community_library_publishing_setting import (
+    CommunityLibraryPublishingSetting,
+)
+from .community_library_setting import CommunityLibrarySetting
 from .course_bulk_register_enabled_setting import (
     CourseBulkRegisterEnabledSetting,
 )
@@ -93,6 +103,10 @@ from .course_gradebook_render_warning_size_setting import (
 from .course_register_enabled_setting import CourseRegisterEnabledSetting
 from .csv_large_file_limit_setting import CsvLargeFileLimitSetting
 from .csv_too_many_errors_limit_setting import CsvTooManyErrorsLimitSetting
+from .default_course_ta_role_setting import DefaultCourseTaRoleSetting
+from .default_course_teacher_role_setting import (
+    DefaultCourseTeacherRoleSetting,
+)
 from .editor_enabled_for_teachers_setting import (
     EditorEnabledForTeachersSetting,
 )
@@ -102,25 +116,57 @@ from .exam_login_max_length_setting import ExamLoginMaxLengthSetting
 from .feedback_threads_initially_collapsed_setting import (
     FeedbackThreadsInitiallyCollapsedSetting,
 )
-from .find_element_interval_setting import FindElementIntervalSetting
-from .find_element_max_tries_setting import FindElementMaxTriesSetting
+from .github_template_repo_enabled_setting import (
+    GithubTemplateRepoEnabledSetting,
+)
+from .grade_viewer_and_editor_on_submission_enabled_setting import (
+    GradeViewerAndEditorOnSubmissionEnabledSetting,
+)
 from .grading_notifications_enabled_setting import (
     GradingNotificationsEnabledSetting,
 )
 from .groups_enabled_setting import GroupsEnabledSetting
+from .hide_code_editor_output_viewer_with_only_quiz_steps_setting import (
+    HideCodeEditorOutputViewerWithOnlyQuizStepsSetting,
+)
+from .hide_empty_rubric_row_description_setting import (
+    HideEmptyRubricRowDescriptionSetting,
+)
 from .incremental_rubric_submission_enabled_setting import (
     IncrementalRubricSubmissionEnabledSetting,
 )
+from .inline_rubric_viewer_enabled_setting import (
+    InlineRubricViewerEnabledSetting,
+)
 from .is_admin_permission_enabled_setting import (
     IsAdminPermissionEnabledSetting,
 )
 from .jwt_access_token_expires_setting import JwtAccessTokenExpiresSetting
 from .linters_enabled_setting import LintersEnabledSetting
 from .login_token_before_time_setting import LoginTokenBeforeTimeSetting
+from .lti1p3_nonce_and_state_validation_enabled_setting import (
+    Lti1p3NonceAndStateValidationEnabledSetting,
+)
+from .lti1p3_parse_most_privileged_role_setting import (
+    Lti1p3ParseMostPrivilegedRoleSetting,
+)
+from .lti1p3_prevent_nonce_reuse_enabled_setting import (
+    Lti1p3PreventNonceReuseEnabledSetting,
+)
+from .lti1p3_system_role_from_context_role_setting import (
+    Lti1p3SystemRoleFromContextRoleSetting,
+)
 from .lti_enabled_setting import LtiEnabledSetting
+from .lti_first_launch_content_id_enabled_setting import (
+    LtiFirstLaunchContentIdEnabledSetting,
+)
+from .lti_launch_data_logging_setting import LtiLaunchDataLoggingSetting
 from .lti_lock_date_copying_enabled_setting import (
     LtiLockDateCopyingEnabledSetting,
 )
+from .lti_unset_deadline_lock_date_enabled_setting import (
+    LtiUnsetDeadlineLockDateEnabledSetting,
+)
 from .max_document_update_size_setting import MaxDocumentUpdateSizeSetting
 from .max_dynamo_file_size_setting import MaxDynamoFileSizeSetting
 from .max_dynamo_submission_size_setting import MaxDynamoSubmissionSizeSetting
@@ -132,23 +178,6 @@ from .max_normal_upload_size_setting import MaxNormalUploadSizeSetting
 from .max_number_of_files_setting import MaxNumberOfFilesSetting
 from .max_plagiarism_matches_setting import MaxPlagiarismMatchesSetting
 from .max_user_setting_amount_setting import MaxUserSettingAmountSetting
-from .metric_evaluation_time_chunk_size_setting import (
-    MetricEvaluationTimeChunkSizeSetting,
-)
-from .metric_evaluation_time_limit_setting import (
-    MetricEvaluationTimeLimitSetting,
-)
-from .metric_event_buffer_size_setting import MetricEventBufferSizeSetting
-from .metric_gathering_enabled_setting import MetricGatheringEnabledSetting
-from .metric_gathering_event_interval_setting import (
-    MetricGatheringEventIntervalSetting,
-)
-from .metric_gathering_expressions_setting import (
-    MetricGatheringExpressionsSetting,
-)
-from .metric_gathering_time_interval_setting import (
-    MetricGatheringTimeIntervalSetting,
-)
 from .min_password_score_setting import MinPasswordScoreSetting
 from .new_auto_test_allowed_initial_build_ids_setting import (
     NewAutoTestAllowedInitialBuildIdsSetting,
@@ -165,6 +194,9 @@ from .new_auto_test_copying_enabled_setting import (
 from .new_auto_test_current_initial_build_ids_setting import (
     NewAutoTestCurrentInitialBuildIdsSetting,
 )
+from .new_auto_test_diff_viewer_enabled_setting import (
+    NewAutoTestDiffViewerEnabledSetting,
+)
 from .new_auto_test_enabled_setting import NewAutoTestEnabledSetting
 from .new_auto_test_initial_build_id_setting import (
     NewAutoTestInitialBuildIdSetting,
@@ -173,6 +205,9 @@ from .new_auto_test_max_dynamodb_size_setting import (
     NewAutoTestMaxDynamodbSizeSetting,
 )
 from .new_auto_test_max_file_size_setting import NewAutoTestMaxFileSizeSetting
+from .new_auto_test_max_output_files_size_setting import (
+    NewAutoTestMaxOutputFilesSizeSetting,
+)
 from .new_auto_test_max_storage_size_setting import (
     NewAutoTestMaxStorageSizeSetting,
 )
@@ -185,8 +220,27 @@ from .new_auto_test_test_max_command_time_setting import (
 from .new_auto_test_test_output_limit_setting import (
     NewAutoTestTestOutputLimitSetting,
 )
+from .new_auto_test_uncollapsing_step_output_delay_setting import (
+    NewAutoTestUncollapsingStepOutputDelaySetting,
+)
 from .notification_poll_time_setting import NotificationPollTimeSetting
+from .output_viewer_animation_limit_lines_count_setting import (
+    OutputViewerAnimationLimitLinesCountSetting,
+)
+from .pearson_templates_setting import PearsonTemplatesSetting
 from .peer_feedback_enabled_setting import PeerFeedbackEnabledSetting
+from .plagiarism_bulk_export_enabled_setting import (
+    PlagiarismBulkExportEnabledSetting,
+)
+from .plagiarism_bulk_export_max_cases_setting import (
+    PlagiarismBulkExportMaxCasesSetting,
+)
+from .plagiarism_pdf_export_enabled_setting import (
+    PlagiarismPdfExportEnabledSetting,
+)
+from .quality_comments_in_code_editor_setting import (
+    QualityCommentsInCodeEditorSetting,
+)
 from .register_enabled_setting import RegisterEnabledSetting
 from .release_message_max_time_setting import ReleaseMessageMaxTimeSetting
 from .render_html_enabled_setting import RenderHtmlEnabledSetting
@@ -195,6 +249,9 @@ from .rubric_enabled_for_teacher_on_submissions_page_setting import (
     RubricEnabledForTeacherOnSubmissionsPageSetting,
 )
 from .rubrics_enabled_setting import RubricsEnabledSetting
+from .sections_in_submission_list_enabled_setting import (
+    SectionsInSubmissionListEnabledSetting,
+)
 from .send_registration_email_setting import SendRegistrationEmailSetting
 from .server_time_correction_enabled_setting import (
     ServerTimeCorrectionEnabledSetting,
@@ -202,16 +259,30 @@ from .server_time_correction_enabled_setting import (
 from .server_time_diff_tolerance_setting import ServerTimeDiffToleranceSetting
 from .server_time_sync_interval_setting import ServerTimeSyncIntervalSetting
 from .setting_token_time_setting import SettingTokenTimeSetting
+from .simple_submission_mode_enabled_setting import (
+    SimpleSubmissionModeEnabledSetting,
+)
+from .simple_submission_navigate_to_latest_editor_session_setting import (
+    SimpleSubmissionNavigateToLatestEditorSessionSetting,
+)
 from .site_email_setting import SiteEmailSetting
+from .sso_infer_global_staff_role_setting import SsoInferGlobalStaffRoleSetting
 from .sso_username_decollision_enabled_setting import (
     SsoUsernameDecollisionEnabledSetting,
 )
+from .staged_assignment_importer_enabled_setting import (
+    StagedAssignmentImporterEnabledSetting,
+)
 from .student_payment_enabled_setting import StudentPaymentEnabledSetting
+from .submissions_page_v2_enabled_setting import (
+    SubmissionsPageV2EnabledSetting,
+)
+from .submissions_per_page_enabled_setting import (
+    SubmissionsPerPageEnabledSetting,
+)
 from .test_submission_copying_on_import_enabled_setting import (
     TestSubmissionCopyingOnImportEnabledSetting,
 )
-from .tour_configurations_setting import TourConfigurationsSetting
-from .tour_polling_interval_setting import TourPollingIntervalSetting
 
 SiteSettingInput = t.Union[
     AutoTestMaxTimeCommandSetting,
@@ -233,11 +304,13 @@ SiteSettingInput = t.Union[
     NewAutoTestMaxFileSizeSetting,
     NewAutoTestBuildOutputLimitSetting,
     NewAutoTestTestOutputLimitSetting,
+    NewAutoTestMaxOutputFilesSizeSetting,
     NewAutoTestCurrentInitialBuildIdsSetting,
     NewAutoTestAllowedInitialBuildIdsSetting,
     NewAutoTestInitialBuildIdSetting,
     NewAutoTestBuildMaxCommandTimeSetting,
     NewAutoTestTestMaxCommandTimeSetting,
+    CodeEditorOutputViewerTitleSetting,
     ExamLoginMaxLengthSetting,
     LoginTokenBeforeTimeSetting,
     MinPasswordScoreSetting,
@@ -280,28 +353,18 @@ SiteSettingInput = t.Union[
     EditorEnabledSetting,
     NewAutoTestEnabledSetting,
     ServerTimeCorrectionEnabledSetting,
-    MetricGatheringEnabledSetting,
     GradingNotificationsEnabledSetting,
     SsoUsernameDecollisionEnabledSetting,
     FeedbackThreadsInitiallyCollapsedSetting,
     MaxUserSettingAmountSetting,
     SendRegistrationEmailSetting,
-    MetricGatheringTimeIntervalSetting,
-    MetricGatheringEventIntervalSetting,
-    MetricEventBufferSizeSetting,
-    MetricEvaluationTimeLimitSetting,
-    MetricEvaluationTimeChunkSizeSetting,
-    MetricGatheringExpressionsSetting,
     ServerTimeDiffToleranceSetting,
     ServerTimeSyncIntervalSetting,
     IsAdminPermissionEnabledSetting,
-    TourPollingIntervalSetting,
-    FindElementIntervalSetting,
-    FindElementMaxTriesSetting,
-    TourConfigurationsSetting,
     AutomaticLti1p3AssignmentImportSetting,
     AssignmentPercentageDecimalsSetting,
     AssignmentPointDecimalsSetting,
+    OutputViewerAnimationLimitLinesCountSetting,
     LtiLockDateCopyingEnabledSetting,
     AssignmentMaxPointsEnabledSetting,
     CourseGradebookEnabledSetting,
@@ -316,6 +379,37 @@ SiteSettingInput = t.Union[
     CanvasCourseIdCopyingEnabledSetting,
     EditorEnabledForTeachersSetting,
     TestSubmissionCopyingOnImportEnabledSetting,
+    NewAutoTestDiffViewerEnabledSetting,
+    StagedAssignmentImporterEnabledSetting,
+    LtiUnsetDeadlineLockDateEnabledSetting,
+    SectionsInSubmissionListEnabledSetting,
+    GithubTemplateRepoEnabledSetting,
+    CommunityLibrarySetting,
+    CommunityLibraryPublishingSetting,
+    Lti1p3SystemRoleFromContextRoleSetting,
+    Lti1p3ParseMostPrivilegedRoleSetting,
+    PlagiarismPdfExportEnabledSetting,
+    PlagiarismBulkExportEnabledSetting,
+    PlagiarismBulkExportMaxCasesSetting,
+    QualityCommentsInCodeEditorSetting,
+    SsoInferGlobalStaffRoleSetting,
+    NewAutoTestUncollapsingStepOutputDelaySetting,
+    AssignmentDescriptionOnTeachersSubmissionsPageSetting,
+    SubmissionsPerPageEnabledSetting,
+    InlineRubricViewerEnabledSetting,
+    LtiFirstLaunchContentIdEnabledSetting,
+    SubmissionsPageV2EnabledSetting,
+    SimpleSubmissionModeEnabledSetting,
+    LtiLaunchDataLoggingSetting,
+    HideCodeEditorOutputViewerWithOnlyQuizStepsSetting,
+    PearsonTemplatesSetting,
+    SimpleSubmissionNavigateToLatestEditorSessionSetting,
+    GradeViewerAndEditorOnSubmissionEnabledSetting,
+    HideEmptyRubricRowDescriptionSetting,
+    DefaultCourseTeacherRoleSetting,
+    DefaultCourseTaRoleSetting,
+    Lti1p3NonceAndStateValidationEnabledSetting,
+    Lti1p3PreventNonceReuseEnabledSetting,
 ]
 SiteSettingInputParser = rqa.Lazy(
     lambda: make_union(
@@ -338,11 +432,13 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(NewAutoTestMaxFileSizeSetting),
         ParserFor.make(NewAutoTestBuildOutputLimitSetting),
         ParserFor.make(NewAutoTestTestOutputLimitSetting),
+        ParserFor.make(NewAutoTestMaxOutputFilesSizeSetting),
         ParserFor.make(NewAutoTestCurrentInitialBuildIdsSetting),
         ParserFor.make(NewAutoTestAllowedInitialBuildIdsSetting),
         ParserFor.make(NewAutoTestInitialBuildIdSetting),
         ParserFor.make(NewAutoTestBuildMaxCommandTimeSetting),
         ParserFor.make(NewAutoTestTestMaxCommandTimeSetting),
+        ParserFor.make(CodeEditorOutputViewerTitleSetting),
         ParserFor.make(ExamLoginMaxLengthSetting),
         ParserFor.make(LoginTokenBeforeTimeSetting),
         ParserFor.make(MinPasswordScoreSetting),
@@ -385,28 +481,18 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(EditorEnabledSetting),
         ParserFor.make(NewAutoTestEnabledSetting),
         ParserFor.make(ServerTimeCorrectionEnabledSetting),
-        ParserFor.make(MetricGatheringEnabledSetting),
         ParserFor.make(GradingNotificationsEnabledSetting),
         ParserFor.make(SsoUsernameDecollisionEnabledSetting),
         ParserFor.make(FeedbackThreadsInitiallyCollapsedSetting),
         ParserFor.make(MaxUserSettingAmountSetting),
         ParserFor.make(SendRegistrationEmailSetting),
-        ParserFor.make(MetricGatheringTimeIntervalSetting),
-        ParserFor.make(MetricGatheringEventIntervalSetting),
-        ParserFor.make(MetricEventBufferSizeSetting),
-        ParserFor.make(MetricEvaluationTimeLimitSetting),
-        ParserFor.make(MetricEvaluationTimeChunkSizeSetting),
-        ParserFor.make(MetricGatheringExpressionsSetting),
         ParserFor.make(ServerTimeDiffToleranceSetting),
         ParserFor.make(ServerTimeSyncIntervalSetting),
         ParserFor.make(IsAdminPermissionEnabledSetting),
-        ParserFor.make(TourPollingIntervalSetting),
-        ParserFor.make(FindElementIntervalSetting),
-        ParserFor.make(FindElementMaxTriesSetting),
-        ParserFor.make(TourConfigurationsSetting),
         ParserFor.make(AutomaticLti1p3AssignmentImportSetting),
         ParserFor.make(AssignmentPercentageDecimalsSetting),
         ParserFor.make(AssignmentPointDecimalsSetting),
+        ParserFor.make(OutputViewerAnimationLimitLinesCountSetting),
         ParserFor.make(LtiLockDateCopyingEnabledSetting),
         ParserFor.make(AssignmentMaxPointsEnabledSetting),
         ParserFor.make(CourseGradebookEnabledSetting),
@@ -421,5 +507,36 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(CanvasCourseIdCopyingEnabledSetting),
         ParserFor.make(EditorEnabledForTeachersSetting),
         ParserFor.make(TestSubmissionCopyingOnImportEnabledSetting),
+        ParserFor.make(NewAutoTestDiffViewerEnabledSetting),
+        ParserFor.make(StagedAssignmentImporterEnabledSetting),
+        ParserFor.make(LtiUnsetDeadlineLockDateEnabledSetting),
+        ParserFor.make(SectionsInSubmissionListEnabledSetting),
+        ParserFor.make(GithubTemplateRepoEnabledSetting),
+        ParserFor.make(CommunityLibrarySetting),
+        ParserFor.make(CommunityLibraryPublishingSetting),
+        ParserFor.make(Lti1p3SystemRoleFromContextRoleSetting),
+        ParserFor.make(Lti1p3ParseMostPrivilegedRoleSetting),
+        ParserFor.make(PlagiarismPdfExportEnabledSetting),
+        ParserFor.make(PlagiarismBulkExportEnabledSetting),
+        ParserFor.make(PlagiarismBulkExportMaxCasesSetting),
+        ParserFor.make(QualityCommentsInCodeEditorSetting),
+        ParserFor.make(SsoInferGlobalStaffRoleSetting),
+        ParserFor.make(NewAutoTestUncollapsingStepOutputDelaySetting),
+        ParserFor.make(AssignmentDescriptionOnTeachersSubmissionsPageSetting),
+        ParserFor.make(SubmissionsPerPageEnabledSetting),
+        ParserFor.make(InlineRubricViewerEnabledSetting),
+        ParserFor.make(LtiFirstLaunchContentIdEnabledSetting),
+        ParserFor.make(SubmissionsPageV2EnabledSetting),
+        ParserFor.make(SimpleSubmissionModeEnabledSetting),
+        ParserFor.make(LtiLaunchDataLoggingSetting),
+        ParserFor.make(HideCodeEditorOutputViewerWithOnlyQuizStepsSetting),
+        ParserFor.make(PearsonTemplatesSetting),
+        ParserFor.make(SimpleSubmissionNavigateToLatestEditorSessionSetting),
+        ParserFor.make(GradeViewerAndEditorOnSubmissionEnabledSetting),
+        ParserFor.make(HideEmptyRubricRowDescriptionSetting),
+        ParserFor.make(DefaultCourseTeacherRoleSetting),
+        ParserFor.make(DefaultCourseTaRoleSetting),
+        ParserFor.make(Lti1p3NonceAndStateValidationEnabledSetting),
+        ParserFor.make(Lti1p3PreventNonceReuseEnabledSetting),
     ),
 )
