@@ -33,6 +33,9 @@ class Tenant:
     #: first be ordered from highest `order_category` to lowest, and then by
     #: name.
     order_category: "int"
+    #: This value states whether the tenant should be hidden from listing if
+    #: the user is not allowed to see hidden tenants.
+    is_hidden: "bool"
     #: The netloc this tenant is hosted on.
     netloc: "str"
 
@@ -83,6 +86,15 @@ class Tenant:
                     " `order_category` to lowest, and then by name."
                 ),
             ),
+            rqa.RequiredArgument(
+                "is_hidden",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "This value states whether the tenant should be hidden"
+                    " from listing if the user is not allowed to see hidden"
+                    " tenants."
+                ),
+            ),
             rqa.RequiredArgument(
                 "netloc",
                 rqa.SimpleValue.str,
@@ -99,6 +111,7 @@ class Tenant:
             "statistics": to_dict(self.statistics),
             "abbreviated_name": to_dict(self.abbreviated_name),
             "order_category": to_dict(self.order_category),
+            "is_hidden": to_dict(self.is_hidden),
             "netloc": to_dict(self.netloc),
         }
         return res
@@ -114,6 +127,7 @@ class Tenant:
             statistics=parsed.statistics,
             abbreviated_name=parsed.abbreviated_name,
             order_category=parsed.order_category,
+            is_hidden=parsed.is_hidden,
             netloc=parsed.netloc,
         )
         res.raw_data = d
